# Changelog

<!--next-version-placeholder-->

## v0.3.0 (2020-12-07)
### Feature
* Accept any callable as the schema ([`2f3d1e1`](https://github.com/kalekundert/parametrize_from_file/commit/2f3d1e15129ebc70e7d5b3a2acbda3e5d7186a4a))

## v0.2.0 (2020-12-04)
### Feature
* Rename the 'key' argument ([`25d7879`](https://github.com/kalekundert/parametrize_from_file/commit/25d7879160c46a1b3d63eb3cad37e184e2c89144))

## v0.1.1 (2020-12-04)
### Fix
* Don't apply the schema to 'id' and 'marks' ([`e18e931`](https://github.com/kalekundert/parametrize_from_file/commit/e18e931749cf83370a88ebadf4a587e07566b41e))

### Documentation
* Tweak some wording ([`f392eb7`](https://github.com/kalekundert/parametrize_from_file/commit/f392eb7f0854706262e54b4970961a56aaabaeed))
* Fix punctuation ([`6aa39db`](https://github.com/kalekundert/parametrize_from_file/commit/6aa39db9a2b654820309a7b47ebf4d1ec8aaca6a))

## v0.1.0 (2020-12-03)
### Feature
* Give more helpful schema errors ([`aac84a0`](https://github.com/kalekundert/parametrize_from_file/commit/aac84a0f16ab1392fdc51e807edfdc6b042b4cc2))

### Documentation
* Initial documentation ([`597abeb`](https://github.com/kalekundert/parametrize_from_file/commit/597abeb790823a807c60bd607e559ab2af445265))

## v0.0.1 (2020-12-02)
### Fix
* Use a functools.wrap() signature compatible with python<=3.8 ([`2e2b60d`](https://github.com/kalekundert/parametrize_from_file/commit/2e2b60dce4083a3b98d77f1fe067b0a0baaad89b))
* Avoid using walrus operator ([`3775077`](https://github.com/kalekundert/parametrize_from_file/commit/37750776baaf6783edb2f279127ffdcc1dafb167))
